==> ejc-jlprogress-impl-3.0.0-20240507.101713-23-sources.jar: com/ejianc/business/jlprogress/quality/bean/DisposeEntity.java <==
package com.ejianc.business.jlprogress.quality.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 质量检测-不合计品处置单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_quality_dispose")
public class DisposeEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 处置单号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="check_code")
    private String checkCode; // 检测单号
    @TableField(value="type")
    private Integer type; // 不合格来源 1-工序检测,2-成品检测,3-原材检测
    @TableField(value="product_id")
    private Long productId; // 产品名称id
    @TableField(value="product_name")
    private String productName; // 产品名称name
    @TableField(value="customer_id")
    private Long customerId; // 客户名称id
    @TableField(value="customer_name")
    private String customerName; // 客户名称name
    @TableField(value="principal_id")
    private Long principalId; // 责任人id
    @TableField(value="principal_name")
    private String principalName; // 责任人name
    @TableField(value="checker_id")
    private Long checkerId; // 检验员id
    @TableField(value="checker_name")
    private String checkerName; // 检验员name
    @TableField(value="check_depart_id")
    private Long checkDepartId; // 检验部门id
    @TableField(value="check_depart_name")
    private String checkDepartName; // 检验部门name
    @TableField(value="product_figure_number")
    private String productFigureNumber; // 产品图号
    @TableField(value="no_num")
    private Integer noNum; // 不合格数
    @TableField(value="response_department")
    private String responseDepartment; // 责任部门
    @TableField(value="description")
    private String description; // 不合格现象描述
    @TableField(value="reason")
    private String reason; // 不合格原因分析
    @TableField(value="conclusion_type")
    private Integer conclusionType; // 结论, 1-轻微,2-一般,3-严重
    @TableField(value="scheme_id")
    private Long schemeId; // 处理方案id
    @TableField(value="scheme_name")
    private String schemeName; // 处理方案name
    @TableField(value="financial_loss")
    private BigDecimal financialLoss; //财务损失
    @TableField(value="accountant_id")
    private Long accountantId; //复核会计id
    @TableField(value="accountant_name")
    private String accountantName; //复核会计name
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCheckCode() {
        return checkCode;
    }

    public void setCheckCode(String checkCode) {
        this.checkCode = checkCode;
    }
    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }
    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public Long getCustomerId() {
        return customerId;
    }

    public void setCustomerId(Long customerId) {
        this.customerId = customerId;
    }
    public String getCustomerName() {
        return customerName;
    }

    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }
    public Long getPrincipalId() {
        return principalId;
    }

    public void setPrincipalId(Long principalId) {
        this.principalId = principalId;
    }
    public String getPrincipalName() {
        return principalName;
    }

    public void setPrincipalName(String principalName) {
        this.principalName = principalName;
    }
    public Long getCheckerId() {
        return checkerId;
    }

    public void setCheckerId(Long checkerId) {
        this.checkerId = checkerId;
    }
    public String getCheckerName() {
        return checkerName;
    }

    public void setCheckerName(String checkerName) {
        this.checkerName = checkerName;
    }
    public Long getCheckDepartId() {
        return checkDepartId;
    }

    public void setCheckDepartId(Long checkDepartId) {
        this.checkDepartId = checkDepartId;
    }
    public String getCheckDepartName() {
        return checkDepartName;
    }

    public void setCheckDepartName(String checkDepartName) {
        this.checkDepartName = checkDepartName;
    }
    public String getProductFigureNumber() {
        return productFigureNumber;
    }

    public void setProductFigureNumber(String productFigureNumber) {
        this.productFigureNumber = productFigureNumber;
    }
    public Integer getNoNum() {
        return noNum;
    }

    public void setNoNum(Integer noNum) {
        this.noNum = noNum;
    }
    public String getResponseDepartment() {
        return responseDepartment;
    }

    public void setResponseDepartment(String responseDepartment) {
        this.responseDepartment = responseDepartment;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }
    public Integer getConclusionType() {
        return conclusionType;
    }

    public void setConclusionType(Integer conclusionType) {
        this.conclusionType = conclusionType;
    }
    public Long getSchemeId() {
        return schemeId;
    }

    public void setSchemeId(Long schemeId) {
        this.schemeId = schemeId;
    }
    public String getSchemeName() {
        return schemeName;
    }

    public void setSchemeName(String schemeName) {
        this.schemeName = schemeName;
    }
    public BigDecimal getFinancialLoss() {
        return financialLoss;
    }

    public void setFinancialLoss(BigDecimal financialLoss) {
        this.financialLoss = financialLoss;
    }
    public Long getAccountantId() {
        return accountantId;
    }

    public void setAccountantId(Long accountantId) {
        this.accountantId = accountantId;
    }
    public String getAccountantName() {
        return accountantName;
    }

    public void setAccountantName(String accountantName) {
        this.accountantName = accountantName;
    }
    
}

==> ejc-jlprogress-impl-3.0.0-20240530.083344-114-sources.jar: com/ejianc/business/jlprogress/quality/bean/DisposeEntity.java <==
package com.ejianc.business.jlprogress.quality.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 质量检测-不合计品处置单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_quality_dispose")
public class DisposeEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 处置单号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="check_code")
    private String checkCode; // 检测单号
    @TableField(value="check_id")
    private Long checkId; // 检测单id
    @TableField(value="check_name")
    private String checkName; // 检测单name
    @TableField(value="type")
    private Integer type; // 不合格来源 1-工序检测,2-成品检测,3-原材检测
    @TableField(value="product_id")
    private Long productId; // 产品名称id
    @TableField(value="product_name")
    private String productName; // 产品名称name
    @TableField(value="customer_id")
    private Long customerId; // 客户名称id
    @TableField(value="customer_name")
    private String customerName; // 客户名称name
    @TableField(value="principal_id")
    private Long principalId; // 责任人id
    @TableField(value="principal_name")
    private String principalName; // 责任人name
    @TableField(value="checker_id")
    private Long checkerId; // 检验员id
    @TableField(value="checker_name")
    private String checkerName; // 检验员name
    @TableField(value="check_depart_id")
    private Long checkDepartId; // 检验部门id
    @TableField(value="check_depart_name")
    private String checkDepartName; // 检验部门name
    @TableField(value="product_figure_number")
    private String productFigureNumber; // 产品图号
    @TableField(value="no_num")
    private Integer noNum; // 不合格数
    @TableField(value="response_department_id")
    private Long responseDepartmentId; // 责任部门
    @TableField(value="response_department_name")
    private String responseDepartmentName; // 责任部门
    @TableField(value="description")
    private String description; // 不合格现象描述
    @TableField(value="reason")
    private String reason; // 不合格原因分析
    @TableField(value="conclusion_type")
    private Integer conclusionType; // 结论, 1-轻微,2-一般,3-严重
    @TableField(value="scheme_id")
    private Long schemeId; // 处理方案id
    @TableField(value="scheme_name")
    private String schemeName; // 处理方案name
    @TableField(value="financial_loss")
    private BigDecimal financialLoss; //财务损失
    @TableField(value="accountant_id")
    private Long accountantId; //复核会计id
    @TableField(value="accountant_name")
    private String accountantName; //复核会计name
    @TableField(value="plan_id")
    private Long planId; //计划单号id
    @TableField(value="plan_name")
    private String planName; //计划单号name
    @TableField(value="plan_code")
    private String planCode; //计划单号code

    public Long getResponseDepartmentId() {
        return responseDepartmentId;
    }

    public void setResponseDepartmentId(Long responseDepartmentId) {
        this.responseDepartmentId = responseDepartmentId;
    }

    public String getResponseDepartmentName() {
        return responseDepartmentName;
    }

    public void setResponseDepartmentName(String responseDepartmentName) {
        this.responseDepartmentName = responseDepartmentName;
    }

    public Long getCheckId() {
        return checkId;
    }

    public void setCheckId(Long checkId) {
        this.checkId = checkId;
    }

    public String getCheckName() {
        return checkName;
    }

    public void setCheckName(String checkName) {
        this.checkName = checkName;
    }

    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }

    public String getPlanName() {
        return planName;
    }

    public void setPlanName(String planName) {
        this.planName = planName;
    }

    public String getPlanCode() {
        return planCode;
    }

    public void setPlanCode(String planCode) {
        this.planCode = planCode;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCheckCode() {
        return checkCode;
    }

    public void setCheckCode(String checkCode) {
        this.checkCode = checkCode;
    }
    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }
    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public Long getCustomerId() {
        return customerId;
    }

    public void setCustomerId(Long customerId) {
        this.customerId = customerId;
    }
    public String getCustomerName() {
        return customerName;
    }

    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }
    public Long getPrincipalId() {
        return principalId;
    }

    public void setPrincipalId(Long principalId) {
        this.principalId = principalId;
    }
    public String getPrincipalName() {
        return principalName;
    }

    public void setPrincipalName(String principalName) {
        this.principalName = principalName;
    }
    public Long getCheckerId() {
        return checkerId;
    }

    public void setCheckerId(Long checkerId) {
        this.checkerId = checkerId;
    }
    public String getCheckerName() {
        return checkerName;
    }

    public void setCheckerName(String checkerName) {
        this.checkerName = checkerName;
    }
    public Long getCheckDepartId() {
        return checkDepartId;
    }

    public void setCheckDepartId(Long checkDepartId) {
        this.checkDepartId = checkDepartId;
    }
    public String getCheckDepartName() {
        return checkDepartName;
    }

    public void setCheckDepartName(String checkDepartName) {
        this.checkDepartName = checkDepartName;
    }
    public String getProductFigureNumber() {
        return productFigureNumber;
    }

    public void setProductFigureNumber(String productFigureNumber) {
        this.productFigureNumber = productFigureNumber;
    }
    public Integer getNoNum() {
        return noNum;
    }

    public void setNoNum(Integer noNum) {
        this.noNum = noNum;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }
    public Integer getConclusionType() {
        return conclusionType;
    }

    public void setConclusionType(Integer conclusionType) {
        this.conclusionType = conclusionType;
    }
    public Long getSchemeId() {
        return schemeId;
    }

    public void setSchemeId(Long schemeId) {
        this.schemeId = schemeId;
    }
    public String getSchemeName() {
        return schemeName;
    }

    public void setSchemeName(String schemeName) {
        this.schemeName = schemeName;
    }
    public BigDecimal getFinancialLoss() {
        return financialLoss;
    }

    public void setFinancialLoss(BigDecimal financialLoss) {
        this.financialLoss = financialLoss;
    }
    public Long getAccountantId() {
        return accountantId;
    }

    public void setAccountantId(Long accountantId) {
        this.accountantId = accountantId;
    }
    public String getAccountantName() {
        return accountantName;
    }

    public void setAccountantName(String accountantName) {
        this.accountantName = accountantName;
    }
    
}
